[glib] Fix documentation issues



commit b876e47e3b623b50dcced6c1c8f6f953c1113753
Author: Matthias Clasen <mclasen redhat com>
Date:   Sat Aug 21 15:34:40 2010 -0400

    Fix documentation issues
    
    Gtk-doc is unhappy if the parameter names don't match between header
    and source.

 gio/gnetworkservice.c |    4 +++-
 gio/gproxy.c          |   18 +++++++++---------
 2 files changed, 12 insertions(+), 10 deletions(-)
---
diff --git a/gio/gnetworkservice.c b/gio/gnetworkservice.c
index dc48772..e46126a 100644
--- a/gio/gnetworkservice.c
+++ b/gio/gnetworkservice.c
@@ -340,6 +340,7 @@ g_network_service_get_scheme (GNetworkService *srv)
 /**
  * g_network_service_set_scheme:
  * @srv: a #GNetworkService
+ * @scheme: a URI scheme
  *
  * Set's the URI scheme used to resolve proxies. By default, the service name
  * is used as scheme.
@@ -347,7 +348,8 @@ g_network_service_get_scheme (GNetworkService *srv)
  * Since: 2.26
  */
 void
-g_network_service_set_scheme (GNetworkService *srv, const gchar *scheme)
+g_network_service_set_scheme (GNetworkService *srv,
+                              const gchar     *scheme)
 {
   g_return_if_fail (G_IS_NETWORK_SERVICE (srv));
 
diff --git a/gio/gproxy.c b/gio/gproxy.c
index bb1e5f6..65c42ad 100644
--- a/gio/gproxy.c
+++ b/gio/gproxy.c
@@ -82,25 +82,25 @@ g_proxy_get_default_for_protocol (const gchar *protocol)
 /**
  * g_proxy_connect:
  * @proxy: a #GProxy
- * @io_stream: a #GIOStream
+ * @connection: a #GIOStream
  * @proxy_address: a #GProxyAddress
  * @cancellable: a #GCancellable
  * @error: return #GError
  *
  * Given @io_stream to communicate with a proxy (eg, a
  * #GSocketConnection that is connected to the proxy server), this
  * does the necessary handshake to connect to @proxy_address, and if
  * required, wraps the #GIOStream to handle proxy payload.
  *
  * Return value: a #GIOStream that will replace @io_stream. This might
  *               be the same as @io_stream, in which case a reference
  *               will be added.
  *
  * Since: 2.26
  */
 GIOStream *
 g_proxy_connect (GProxy            *proxy,
-		 GIOStream         *io_stream,
+		 GIOStream         *connection,
 		 GProxyAddress     *proxy_address,
 		 GCancellable      *cancellable,
 		 GError           **error)
@@ -112,7 +112,7 @@ g_proxy_connect (GProxy            *proxy,
   iface = G_PROXY_GET_IFACE (proxy);
 
   return (* iface->connect) (proxy,
-			     io_stream,
+			     connection,
 			     proxy_address,
 			     cancellable,
 			     error);
@@ -121,7 +121,7 @@ g_proxy_connect (GProxy            *proxy,
 /**
  * g_proxy_connect_async:
  * @proxy: a #GProxy
- * @io-stream: a #GIOStream
+ * @connection: a #GIOStream
  * @proxy_address: a #GProxyAddress
  * @cancellable: a #GCancellable
  * @callback: a #GAsyncReadyCallback
@@ -133,7 +133,7 @@ g_proxy_connect (GProxy            *proxy,
  */
 void
 g_proxy_connect_async (GProxy               *proxy,
-		       GIOStream            *io_stream,
+		       GIOStream            *connection,
 		       GProxyAddress        *proxy_address,
 		       GCancellable         *cancellable,
 		       GAsyncReadyCallback   callback,
@@ -146,7 +146,7 @@ g_proxy_connect_async (GProxy               *proxy,
   iface = G_PROXY_GET_IFACE (proxy);
 
   (* iface->connect_async) (proxy,
-			    io_stream,
+			    connection,
 			    proxy_address,
 			    cancellable,
 			    callback,
@@ -82,25 +82,25 @@ g_proxy_get_default_for_protocol (const gchar *protocol)
  * @error: return #GError
  *
- * Given @io_stream to communicate with a proxy (eg, a
+ * Given @connection to communicate with a proxy (eg, a
  * #GSocketConnection that is connected to the proxy server), this
  * does the necessary handshake to connect to @proxy_address, and if
@@ -82,25 +82,25 @@ g_proxy_get_default_for_protocol (const gchar *protocol)
  * required, wraps the #GIOStream to handle proxy payload.
  *
- * Return value: a #GIOStream that will replace @io_stream. This might
- *               be the same as @io_stream, in which case a reference
+ * Return value: a #GIOStream that will replace @connection. This might
+ *               be the same as @connection, in which case a reference
  *               will be added.
  *



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]